==> fritzing_0.7.10b.orig.tar.bz2: fritzing-0.7.10b.source/src/items/moduleidnames.h <==
/*******************************************************************

Part of the Fritzing project - http://fritzing.org
Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de

Fritzing is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fritzing is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public Licensetriple
along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.

********************************************************************

$Revision: 6505 $:
$Author: irascibl@gmail.com $:
$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $

********************************************************************/

#ifndef MODULEIDNAMES_H
#define MODULEIDNAMES_H

#include <QString>

class ModuleIDNames
{
public:
	static const QString ModuleIDNameSuffix;
	static const QString RulerModuleIDName;
	static const QString BreadboardModuleIDName;
	static const QString FullPlusBreadboardModuleIDName;
	static const QString RectanglePCBModuleIDName;
	static const QString TwoSidedRectanglePCBModuleIDName;
	static const QString EllipsePCBModuleIDName;
	static const QString TwoSidedEllipsePCBModuleIDName;
	static const QString NoteModuleIDName;
	static const QString WireModuleIDName;
	static const QString JumperModuleIDName;
	static const QString GroundPlaneModuleIDName;
	static const QString GroundModuleIDName;
	static const QString PowerModuleIDName;
	static const QString NetLabelModuleIDName;
	static const QString JustPowerModuleIDName;
	static const QString ResistorModuleIDName;
	static const QString LogoTextModuleIDName;
	static const QString LogoImageModuleIDName;
	static const QString Copper0LogoTextModuleIDName;
	static const QString Copper0LogoImageModuleIDName;
	static const QString Copper1LogoTextModuleIDName;
	static const QString Copper1LogoImageModuleIDName;
	static const QString SchematicLogoTextModuleIDName;
	static const QString SchematicLogoImageModuleIDName;
	static const QString BoardLogoImageModuleIDName;
	static const QString OneLayerBoardLogoImageModuleIDName;
	static const QString HoleModuleIDName;
	static const QString ViaModuleIDName;
	static const QString PadModuleIDName;
	static const QString Copper0PadModuleIDName;
	static const QString CapacitorModuleIDName;
	static const QString CrystalModuleIDName;
	static const QString ZenerDiodeModuleIDName;
	static const QString ThermistorModuleIDName;
	static const QString PotentiometerModuleIDName;
	static const QString InductorModuleIDName;
	static const QString LEDModuleIDName;
	static const QString ColorLEDModuleIDName;
	static const QString ColorFluxLEDModuleIDName;
	static const QString PerfboardModuleIDName;
	static const QString StripboardModuleIDName;
	static const QString SpacerModuleIDName;
	static const QString SchematicFrameModuleIDName;
    static const QString CopperBlockerModuleIDName;
    static const QString Copper1BlockerModuleIDName;
    static const QString Copper0BlockerModuleIDName;
};

#endif

==> fritzing_0.8.3b.orig.tar.bz2: fritzing-0.8.3b.source/src/items/moduleidnames.h <==
/*******************************************************************

Part of the Fritzing project - http://fritzing.org
Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de

Fritzing is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fritzing is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public Licensetriple
along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.

********************************************************************

$Revision: 6947 $:
$Author: irascibl@gmail.com $:
$Date: 2013-04-03 06:45:22 +0200 (Mi, 03. Apr 2013) $

********************************************************************/

#ifndef MODULEIDNAMES_H
#define MODULEIDNAMES_H

#include <QString>

class ModuleIDNames
{
public:
	static const QString ModuleIDNameSuffix;
	static const QString RulerModuleIDName;
	static const QString BreadboardModuleIDName;
	static const QString FullPlusBreadboardModuleIDName;
	static const QString RectanglePCBModuleIDName;
	static const QString TwoSidedRectanglePCBModuleIDName;
	static const QString EllipsePCBModuleIDName;
	static const QString TwoSidedEllipsePCBModuleIDName;
	static const QString NoteModuleIDName;
	static const QString WireModuleIDName;
	static const QString JumperModuleIDName;
	static const QString GroundPlaneModuleIDName;
	static const QString GroundModuleIDName;
	static const QString PowerModuleIDName;
	static const QString TwoPowerModuleIDName;
	static const QString NetLabelModuleIDName;	
    static const QString PowerLabelModuleIDName;
	static const QString LeftNetLabelModuleIDName;
	static const QString JustPowerModuleIDName;
	static const QString ResistorModuleIDName;
	static const QString LogoTextModuleIDName;
	static const QString LogoImageModuleIDName;
	static const QString Copper0LogoTextModuleIDName;
	static const QString Copper0LogoImageModuleIDName;
	static const QString Copper1LogoTextModuleIDName;
	static const QString Copper1LogoImageModuleIDName;
	static const QString SchematicLogoTextModuleIDName;
	static const QString SchematicLogoImageModuleIDName;
	static const QString BreadboardLogoTextModuleIDName;
	static const QString BreadboardLogoImageModuleIDName;
	static const QString BoardLogoImageModuleIDName;
	static const QString OneLayerBoardLogoImageModuleIDName;
	static const QString HoleModuleIDName;
	static const QString ViaModuleIDName;
	static const QString PadModuleIDName;
	static const QString Copper0PadModuleIDName;
	static const QString CapacitorModuleIDName;
	static const QString CrystalModuleIDName;
	static const QString ZenerDiodeModuleIDName;
	static const QString ThermistorModuleIDName;
	static const QString PotentiometerModuleIDName;
	static const QString InductorModuleIDName;
	static const QString LEDModuleIDName;
	static const QString ColorLEDModuleIDName;
	static const QString ColorFluxLEDModuleIDName;
	static const QString PerfboardModuleIDName;
	static const QString StripboardModuleIDName;
	static const QString Stripboard2ModuleIDName;
	static const QString SpacerModuleIDName;
	static const QString SchematicFrameModuleIDName;
    static const QString CopperBlockerModuleIDName;
    static const QString Copper1BlockerModuleIDName;
    static const QString Copper0BlockerModuleIDName;
};

#endif
